"""Server configuration from environment variables."""

from __future__ import annotations

from pydantic_settings import BaseSettings


class Settings(BaseSettings):
    db_path: str = "prooftrail.db"
    admin_secret: str  # REQUIRED -- set PROOFTRAIL_ADMIN_SECRET env var

    model_config = {"env_prefix": "PROOFTRAIL_"}


settings = Settings()
